import os
import setuptools

with open("/home/runner/termux-1/tikapipy/README.md", "r") as fh:
    long_description = fh.read()

with open('/home/runner/termux-1/tikapipy/requirements.txt') as f:
    required = f.read().splitlines()

setuptools.setup(
    name="tikapipy",
    version="1.0.9",
    author="jiroawesome",
    description="An api-wrapper for https://tiktok.jiroawesome.tech/.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jiroawesome/tikapipy",
    project_urls={
        "Bug Tracker": "https://github.com/jiroawesome/tikapipy/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    package_data={'': ['**/*']},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=required
)


import requests, json

class TikApi(object):
  def __init__(self, key=None):
    self._key = key
    self.base_url = "https://tiktok.jiroawesome.tech"

  def xss_stub(self, payload):
    try:
        url = self.base_url + "/xssstub"
        data = {"key": self._key, "payload": payload}
        resp = requests.post(url, data=data).json()
        if resp['status'] == 0:
            return 'Invalid API-Key'
        elif resp['status'] == 1:
            return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
        elif resp['status'] == 5:
            return resp['result']['xss']
    except json.decoder.JSONDecodeError:
        return 'Invalid parameter has been received.'

  def xgorgon(self, url, cookies):
    try:
        url = self.base_url + "/xgorgon"
        data = {"key": self._key, "url": url, "cookies": cookies}
        resp = requests.post(url, data=data).json()
        if resp['status'] == 0:
            return 'Invalid API-Key'
        elif resp['status'] == 1:
            return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
        elif resp['status'] == 5:
            return resp['result']['gorgon']
    except json.decoder.JSONDecodeError:
        return 'Invalid parameter has been received.'

  def xkhronos(self, url, cookies):
    try:
        url = self.base_url + "/xkhronos"
        data = {"key": self._key, "url": url, "cookies": cookies}
        resp = requests.post(url, data=data).json()
        if resp['status'] == 0:
            return 'Invalid API-Key'
        elif resp['status'] == 1:
            return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
        elif resp['status'] == 5:
            return resp['result']['khronos']
    except json.decoder.JSONDecodeError:
        return 'Invalid parameter has been received.'